==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/outputs/GetNamespaceTopicEventSubscriptionDeliveryAttributesResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.outputs

import com.pulumi.core.Either
import kotlin.Suppress
import kotlin.collections.List

/**
 * Result of the Get delivery attributes operation.
 * @property value A collection of DeliveryAttributeMapping
 */
public data class GetNamespaceTopicEventSubscriptionDeliveryAttributesResult(
    public val `value`:
    List<Either<DynamicDeliveryAttributeMappingResponse, StaticDeliveryAttributeMappingResponse>>? =
        null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.eventgrid.outputs.GetNamespaceTopicEventSubscriptionDeliveryAttributesResult):
            GetNamespaceTopicEventSubscriptionDeliveryAttributesResult =
            GetNamespaceTopicEventSubscriptionDeliveryAttributesResult(
                `value` = javaType.`value`().map({ args0 ->
                    args0.transform(
                        { args0 ->
                            args0.let({ args0 ->
                                com.pulumi.azurenative.eventgrid.kotlin.outputs.DynamicDeliveryAttributeMappingResponse.Companion.toKotlin(args0)
                            })
                        },
                        { args0 ->
                            args0.let({ args0 ->
                                com.pulumi.azurenative.eventgrid.kotlin.outputs.StaticDeliveryAttributeMappingResponse.Companion.toKotlin(args0)
                            })
                        },
                    )
                }),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/outputs/GetNamespaceTopicEventSubscriptionDeliveryAttributesResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.outputs

import com.pulumi.core.Either
import kotlin.Suppress
import kotlin.collections.List

/**
 * Result of the Get delivery attributes operation.
 * @property value A collection of DeliveryAttributeMapping
 */
public data class GetNamespaceTopicEventSubscriptionDeliveryAttributesResult(
    public val `value`: List<Either<DynamicDeliveryAttributeMappingResponse, StaticDeliveryAttributeMappingResponse>>? =
        null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.eventgrid.outputs.GetNamespaceTopicEventSubscriptionDeliveryAttributesResult): GetNamespaceTopicEventSubscriptionDeliveryAttributesResult =
            GetNamespaceTopicEventSubscriptionDeliveryAttributesResult(
                `value` = javaType.`value`().map({ args0 ->
                    args0.transform(
                        { args0 ->
                            args0.let({ args0 ->
                                com.pulumi.azurenative.eventgrid.kotlin.outputs.DynamicDeliveryAttributeMappingResponse.Companion.toKotlin(args0)
                            })
                        },
                        { args0 ->
                            args0.let({ args0 ->
                                com.pulumi.azurenative.eventgrid.kotlin.outputs.StaticDeliveryAttributeMappingResponse.Companion.toKotlin(args0)
                            })
                        },
                    )
                }),
            )
    }
}
